% CALIBRATING A LABOR SUPPLY MODEL
% hours.m
% Numerical Methods for Macroeconomists, by Jeremy Greenwood and Ricardo 
% Marto, Copywrite, Jeremy Greenwood

clear all
clc
global h1900 h2018 w1900 w2018 
h1900 = 63/112;  % Hours worked 1900--males
h2018 = 44/112;  % Hours worked 2018
w1900 = 1;       % Normalized wage, 1900  
w2018 = exp(0.01732*(2018-1900));    % Real wage, 2018
% Solve for the parameter values that hit the two data targets using two
% equations.
guess = [.3 2];  % Guesses for theta and rho 
parvalues = fsolve(@focs, guess); % Call up nonlinear equation solver.
% Check answer is valid
if abs( focs(parvalues) ) >= 1.0e-8
    disp('Zero not found')
    disp(parvalues)
end
theta = parvalues(1);
rho   = parvalues(2);
% Check that parameters are theoretically valid; ie, rho > 0 
% and 0 < theta < 1.
if rho <= 0
    disp('Not legitimate parameter value for rho')
end
if theta <=0 || 1-theta <=0        % || is logical or statement
    disp('Not legitmate value for theta')
end
% Display answer
disp('theta rho')
disp( [theta, rho] )
