% Monopoly Problem--solved by maximizing
% Main Program
% main.m
% Numerical Methods for Macroeconomists--Greenwood and Marto

clear all % Clear all numbers from previous runs
clc       % Clear screen 
global alpha beta gamma

% Set parameters for model

% Demand curve
alpha = 1;   % constant
beta  = 0.5; % slope
% Cost function
gamma = 0.5; % quadratic term

% Reasonable bounds on problem
lb = 0;           % lower bound
ub = alpha/beta;  % upper bound

% Plot the Monopolist's Objective Function

% Construct grid of output points
ogrid = lb:alpha/(beta*100):ub;
% ogrid runs from 0 to alpha/beta in 
% increments of alpha/(beta*100)

% Plot the monopolist's objective function
figure(1)
plot(ogrid,-nprofits(ogrid))
title('Objective Function', 'Fontsize', 18)
xlabel('Output', 'Fontsize', 16)
ylabel('Profits', 'Fontsize', 16)
 


% Call up MATLAB minimizer to solve for output
output =  fminbnd(@nprofits,lb,ub) ;  % nprofits is the objective function

price   = alpha - beta*output/2;
cost    = gamma*output^2/2;
profits = price*output - cost;
markup  = price/(gamma*output);

% Display results

disp ('Results for the monopoly model')
disp ('output, price, profits, and markup')
disp ([output price profits markup])

% Discrete maximization
oset = lb:8/99:ub;                     % Discretize domain for maximization
[maxvalue, opoint] = max(-nprofits(oset));             % Find optimal point
% maxvalue = maximal value of objective function
% opoint = point number of the optimal value of output
% oset(opoint) = optimal level of output 

price   = alpha - beta*oset(opoint)/2;   
cost    = gamma*oset(opoint)^2/2;
profits = price*oset(opoint) - cost;
markup  = price/(gamma*oset(opoint));

% Display results

disp ('Results for the monopoly model--discrete maximization')
disp ('output, price, profits, and markup')
disp ([oset(opoint) price profits markup])

% Call up MATLAB particle swarm algorithm to solve for output
% Requires optimization toolbox
output =  particleswarm(@nprofits,1,lb,ub);  

price   = alpha - beta*output/2;
cost    = gamma*output^2/2;
profits = price*output - cost;
markup  = price/(gamma*output);

disp(' ')
disp ('Results for the monopoly model--particle swarm maximization')
disp ('output, price, profits, and markup')
disp ([output price profits markup])

% Export data
% Create a table to be used for exporting data for plotting profits
T = table(ogrid', -nprofits(ogrid)','VariableNames',{'Grid' 'Profits'});
% Export the table to an EXCEL file
filename = 'Monopoly.xlsx';
writetable(T,filename)  
% Create a table to be used for exporting data--discrete case grid
D = table( oset',zeros(length(oset),1),'VariableNames',{'Grid' 'Yvalue'});
% Export the table to an EXCEL file
filename = 'MonopolyGrid.xlsx';
writetable(D,filename)  


